/* ----------------------------------------
 * Origin  : GFI INFORMATIQUE 
 * Project : CDPP Propagation Tool 
 * ----------------------------------------
 * History 
 * Version : 17/11/2017 : SCA : V2.2.2
 *  Creation
 * Version : 25/11/2022 : LBE : V2.6
 * DM-ID : Redmine#10630 : AMDA zoom type
 * ----------------------------------------
 */
package fr.tlse.irap.pt.client.controller.tools.plot;

import fr.tlse.irap.pt.client.controller.tools.plot.FluxPlotModel.FluxMeasure;
import fr.tlse.irap.pt.client.controller.tools.plot.FluxPlotModel.FluxType;
import fr.tlse.irap.flare.Flare.FlareType;

public interface IFluxPlotMenu  {
	public void runShowFlux(FluxType fType, FluxMeasure fMeasure, int index);
	public void runShowAllFlux(FluxType fType);
	public void runShowAllFlares();
	public void runShowFlares(FlareType fType);
	public void runSetZoom();
	public void runResetZoom();
}
